const express = require('express');

const User = require('../service/UserService');
const {default: expressPlayground} = require("graphql-playground-middleware-express");
const {extractToken} = require("../utils/writer");
const {response} = require("express");

const authRouter = express.Router();

authRouter.post('/', async (req, res) => {
    try {
        const response = await User.createUser(req.body);
        if (response.status === undefined) {
            res.json(response);
        } else {
            res.status(response.status).json(response);
        }
    } catch (error) {
        res.status(response.status).json(response);
    }
});

authRouter.post('/login', async (req, res, next) => {
    try {
        const {username, password} = req.body;
        const response = await User.authenticateLocal(username, password);
        if (response.status === undefined) {
            res.json(response);
        } else {
            res.status(response.status).json(response);
        }
    } catch (error) {
        const errorStatus = error.status || 500;
        return res.status(errorStatus).send(error.message || error);
    }
});

authRouter.post('/logout', extractToken, async (req, res) => {
    try {
        const response = await User.logoutUser(req.token);
        if (response.status === undefined) {
            res.json(response);
        } else {
            res.status(response.status).json(response);
        }
    } catch (error) {
        res.status(500).json({message: error.message});
    }
});

module.exports = authRouter;
